!Control file for program Smooth_x_y_data.for
! Revision of program involving a change in the control file on this date:
   02/29/12
! As many comment lines as desired, each starting with "!"
! The string "pp:" indicates a new set of processing parameters
! to be applied to the following smc files.  The parameters are given on the
! lines following "pp:", until the next "pp:" line or until "stop" is 
! encountered.
!
! -----------------------------------------------------------------------------
!
! Meaning of smoothing input parameters
!
! NO SMOOTHING
! itype = 0
! SMOOTHING OVER EQUALLY SPACED FREQUENCIES
! itype = 1: box weighting function
!   smooth_param = width of box weighting function (x units)
! itype = 2: triangular weighting function
!   smooth_param = width of triangular weighting function (x units)
! SMOOTHING OVER LOGARITHMICALLY SPACED FREQUENCIES
! itype = 3: box weighting function
!   smooth_param = xi, which is the fraction of a decade for the
!                  box weighting function 
! itype = 4: triangular weighting function
!   smooth_param = xi, which is the fraction of a decade for the
!                  triangular weighting function 
! itype = 5: Konno and Ohmachi weighting function (see BSSA 88, 228-241)
!   smooth_param = xi, which is the fraction of a decade for which
!                  the Konno and Ohmachi weighting function is greater
!                  than 0.043.(it is related to
!                  their smoothing parameter b by the equation
!                  b = 4.0/smooth_param, so we have this correspondence between
!                  b and smooth_param
!                         b smooth_param 
!                        10         0.40
!                        20         0.20
!                        40         0.10
!                  
!                  b = 40 seems to be commonly used, but I do not think that it
!                  gives enough smoothing; I PREFER SMOOTH_PARAM = 0.2, 
!                  corresponding to b = 20. 
!
! ipow = power of y to be smoothed (2 = smoothing energy spectrum)
!
! dx_smooth: Note: need df_smooth for linearly-spaced smoothers. 
! For general x data, it is
! the spacing between x values, assumed to be constant.  If itype = 1 or 2,
! dx_smooth is obtained as x_in(2)-x_in(1).  The reason for
! including it as an input parameter is to "fool" the
! program to do smoothing over a specified number of points by
! setting dx_smooth = 1 and smooth_param = number of points (including 
! points with zero weight at ends; e.g., smooth_param = 5 will 
! give a smoother with weights 0, 1/4, 2/4, 1/4, 0; smooth_param
! should be odd).
!
! Meaning of x output specification parameters:
!
!Specify x values for output (y/n):
! <enter Y or N>
!x output specification: 
!  If specify_xout = Y, then enter the 
!    nxout, xout(1), xout(2)..., xout(nxout)
!  If specify_xout = N, then enter 
!    xout_low, xout_high, log-spaced (0=N, 1=Y), xout_param
!         if xout_param = 0.0, there is no interpolation, and the xin values 
!            are used between xout_low and xout_high (if want all xin values, set
!            xout_low and xout_high to values outside the range of xin(low) and xin(high) 
!              (log-spaced is ignored).
!         if xout_param /= 0.0 and log-spaced = 0, then xout_param is the spacing of the
!            interpolated x values between xout_low and xout_high
!         if xout_param /= 0.0 and log-spaced = 1, then xout_param is the number of 
!            interpolated x between xout_low and xout_high
! -----------------------------------------------------------------------------
!
!Name of summary file:
 smooth_x_y_data.sum
!A set of parameters and files:
PP: new set of parameters
!smoothing: itype, ipow, dx_smooth (not used if itype >= 3, otherwise x_in spacing), smooth_param
! (see above for the meaning of these input parameters):
   0 1 0.0 0.20
!Specify x values for output (y/n)::
  N
!x output specification (if (specify_xout) then nxout, xout(1)...xout(nxout) ELSE
!             xout_low, xout_high, flag_for_xout_log_spacing (0=N, 1=Y), xout_param)                      
   0.0 50.0 0 0.0 
!character string to append to filename:
   .smooth_ko_0.2.col
!N lines to skip to get to data
 1
!N columns to read, columns for x and y columns 
  3 1 3
!Files to process:
 x_y_data.txt
stop
  